==> kubernetes-model-admissionregistration-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/admission/v1/AdmissionResponseBuilder.java <==
package io.fabric8.kubernetes.api.model.admission.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AdmissionResponseBuilder extends io.fabric8.kubernetes.api.model.admission.v1.AdmissionResponseFluentImpl<io.fabric8.kubernetes.api.model.admission.v1.AdmissionResponseBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.admission.v1.AdmissionResponse,io.fabric8.kubernetes.api.model.admission.v1.AdmissionResponseBuilder>{
  public AdmissionResponseBuilder() {
    this(false);
  }
  public AdmissionResponseBuilder(java.lang.Boolean validationEnabled) {
    this(new AdmissionResponse(), validationEnabled);
  }
  public AdmissionResponseBuilder(io.fabric8.kubernetes.api.model.admission.v1.AdmissionResponseFluent<?> fluent) {
    this(fluent, false);
  }
  public AdmissionResponseBuilder(io.fabric8.kubernetes.api.model.admission.v1.AdmissionResponseFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new AdmissionResponse(), validationEnabled);
  }
  public AdmissionResponseBuilder(io.fabric8.kubernetes.api.model.admission.v1.AdmissionResponseFluent<?> fluent,io.fabric8.kubernetes.api.model.admission.v1.AdmissionResponse instance) {
    this(fluent, instance, false);
  }
  public AdmissionResponseBuilder(io.fabric8.kubernetes.api.model.admission.v1.AdmissionResponseFluent<?> fluent,io.fabric8.kubernetes.api.model.admission.v1.AdmissionResponse instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAllowed(instance.getAllowed()); 
    fluent.withAuditAnnotations(instance.getAuditAnnotations()); 
    fluent.withPatch(instance.getPatch()); 
    fluent.withPatchType(instance.getPatchType()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withUid(instance.getUid()); 
    fluent.withWarnings(instance.getWarnings()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public AdmissionResponseBuilder(io.fabric8.kubernetes.api.model.admission.v1.AdmissionResponse instance) {
    this(instance,false);
  }
  public AdmissionResponseBuilder(io.fabric8.kubernetes.api.model.admission.v1.AdmissionResponse instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAllowed(instance.getAllowed()); 
    this.withAuditAnnotations(instance.getAuditAnnotations()); 
    this.withPatch(instance.getPatch()); 
    this.withPatchType(instance.getPatchType()); 
    this.withStatus(instance.getStatus()); 
    this.withUid(instance.getUid()); 
    this.withWarnings(instance.getWarnings()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.admission.v1.AdmissionResponseFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.admission.v1.AdmissionResponse build() {
    AdmissionResponse buildable = new AdmissionResponse(fluent.getAllowed(),fluent.getAuditAnnotations(),fluent.getPatch(),fluent.getPatchType(),fluent.getStatus(),fluent.getUid(),fluent.getWarnings());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AdmissionResponseBuilder that = (AdmissionResponseBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-admissionregistration-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/admission/v1/AdmissionResponseBuilder.java <==
package io.fabric8.kubernetes.api.model.admission.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class AdmissionResponseBuilder extends AdmissionResponseFluentImpl<AdmissionResponseBuilder> implements VisitableBuilder<AdmissionResponse,AdmissionResponseBuilder>{
  public AdmissionResponseBuilder() {
    this(false);
  }
  public AdmissionResponseBuilder(Boolean validationEnabled) {
    this(new AdmissionResponse(), validationEnabled);
  }
  public AdmissionResponseBuilder(AdmissionResponseFluent<?> fluent) {
    this(fluent, false);
  }
  public AdmissionResponseBuilder(AdmissionResponseFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new AdmissionResponse(), validationEnabled);
  }
  public AdmissionResponseBuilder(AdmissionResponseFluent<?> fluent,AdmissionResponse instance) {
    this(fluent, instance, false);
  }
  public AdmissionResponseBuilder(AdmissionResponseFluent<?> fluent,AdmissionResponse instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAllowed(instance.getAllowed()); 
    fluent.withAuditAnnotations(instance.getAuditAnnotations()); 
    fluent.withPatch(instance.getPatch()); 
    fluent.withPatchType(instance.getPatchType()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withUid(instance.getUid()); 
    fluent.withWarnings(instance.getWarnings()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public AdmissionResponseBuilder(AdmissionResponse instance) {
    this(instance,false);
  }
  public AdmissionResponseBuilder(AdmissionResponse instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAllowed(instance.getAllowed()); 
    this.withAuditAnnotations(instance.getAuditAnnotations()); 
    this.withPatch(instance.getPatch()); 
    this.withPatchType(instance.getPatchType()); 
    this.withStatus(instance.getStatus()); 
    this.withUid(instance.getUid()); 
    this.withWarnings(instance.getWarnings()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  AdmissionResponseFluent<?> fluent;
  Boolean validationEnabled;
  public AdmissionResponse build() {
    AdmissionResponse buildable = new AdmissionResponse(fluent.getAllowed(),fluent.getAuditAnnotations(),fluent.getPatch(),fluent.getPatchType(),fluent.getStatus(),fluent.getUid(),fluent.getWarnings());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
